#
# spec file for package python-wolframalpha
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-wolframalpha
Version:        5.0.0
Release:        3.6
Summary:        WolframAlpha 2.0 API client
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/jaraco/wolframalpha
Source:         https://files.pythonhosted.org/packages/source/w/wolframalpha/wolframalpha-%{version}.tar.gz
BuildRequires:  %{python_module setuptools_scm >= 1.9}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-jaraco.context
Requires:       python-more-itertools
Requires:       python-xmltodict
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module jaraco.context}
BuildRequires:  %{python_module more-itertools}
BuildRequires:  %{python_module pytest >= 3.5}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module xmltodict}
# /SECTION
%python_subpackages

%description
Python Client built against the Wolfram|Alpha (http://wolframalpha.com)
v2.0 API.

%prep
%setup -q -n wolframalpha-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# we do not provide python-pmxbot
rm wolframalpha/{test_,}pmxbot.py
%pytest -k 'not test_pmxbot'

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Mon Jan 29 2024 Dirk Müller <dmueller@suse.com>
- switch to modern pythonstack
* Thu Sep  8 2022 Steve Kowalik <steven.kowalik@suse.com>
- Add more-itertools to BuildRequires.
* Mon Aug 30 2021 Matej Cepl <mcepl@suse.com>
- Fix name of the python-more-itertools package.
* Fri Aug 27 2021 pgajdos@suse.com
- version update to 5.0.0
  v5.0.0
  ======
  * Rewrote object model to load objects more automatically.
    API is mostly compatible, but there may be some rare
    uses that may need some adjustment. In particular,
    access to 'children' properties ('pods', 'subpods',
    'assumptions', 'warnings') are exposed as loaded through
    their singular names (without transforms or defaults) but
    exposed as iterable (empty by default) through the plural
    names.
  v4.3.1
  ======
  * Fixed implementation flaw in ``Results.details``.
  * Test coverage is now 100%%.
  v4.3.0
  ======
  * Added ``Client.from_env()`` to initialize a client loading the
    API key from the keyring or environment.
  * #13: ``Result`` objects now resolve as False and return empty
    ``info`` and ``pods`` attributes when query was unsuccessful.
  v4.2.0
  ======
  * #28: Adapt to support API change from ``.plainText`` to
    ``.plaintext``.
  * Moved usage guide to source and published through the docs
    and validate the usage with doctests.
  v4.1.1
  ======
  * #26: Fix error when ``always_iterable`` recognizes a dict
    as a list of keys.
  v4.1.0
  ======
  * #21: Adapt to support API change from ``.text`` to ``.plainText``.
  * Refreshed package metadata.
  v4.0.0
  ======
  * Require Python 3.6 or later.
- test the package
* Sat Dec 22 2018 Todd R <toddrme2178@gmail.com>
- Update to 3.0.1
  * Refreshed project metadata.
* Sun Mar  4 2018 alarrosa@suse.com
- Add LICENSE file. The pypi page states that this is released under
  a MIT license but the code doesn't include a copy. I submitted a
  pull request to the code and use that for now.
* Tue Sep  5 2017 alarrosa@suse.com
- Initial release of python-wolframalpha 3.0
